@@ -1,7 +1,5 @@
-use crate::log::{println_label, OutputLabel};
 use clap::Parser;
 use git2::Config as GitConfig;
-use std::sync::atomic::AtomicBool;
 
 #[derive(Parser)]
 #[clap(name = "git-leave", about, version, author, long_about = None)]
@@ -13,15 +11,8 @@ pub struct Arguments {
 	/// Use git config default folder value for the directory to search in
 	#[clap(short, long)]
 	pub default: bool,
-
-	/// Don't trim output path (useful for debugging)
-	#[clap(long)]
-	pub no_trim: bool,
 }
 
-/// The atomic bool to store the value of the `--no-trim` flag
-pub static TRIM_OUTPUT: AtomicBool = AtomicBool::new(true);
-
 // Keys used in `.gitconfig` file
 const CONFIG_KEY_DEFAULT_FOLDER: &str = "leaveTool.defaultFolder";
 
@@ -40,10 +31,7 @@ pub fn get_related_config() -> Option<GitLeaveConfig> {
 	let config = match GitConfig::open(&config_path) {
 		Ok(config) => config,
 		Err(err) => {
-			println_label(
-				OutputLabel::Error,
-				format!("Could not open global config: {}", err),
-			);
+			eprintln!("Could not open global config: {}", err);
 
 			return None;
 		}
