@@ -1,5 +1,5 @@
 pub mod config;
-pub mod crawl;
+mod crawl;
 pub mod git;
 
 pub use crawl::crawl_directory_for_repos;
